@@ -1,25 +1,8 @@
 # -*- coding: utf-8 -*-
+#       Created on Thu Dec  3 22:31:16 2020
+#       Author: Kouadio K.Laurent<etanoyau@gmail.com>
+#       Licence: LGPL
 """
-===============================================================================
-    Copyright © 2021  Kouadio K.Laurent
-    
-    This file is part of pyCSAMT.
-    
-    pyCSAMT is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    pyCSAMT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-    
-    You should have received a copy of the GNU Lesser General Public License
-    along with pyCSAMT.  If not, see <https://www.gnu.org/licenses/>.
-
-===============================================================================
-
 .. _module-j:: `pycsamt.ff.core.j
 
    :synopsis: Deal with J files.  The J class can read and write an A.G.Jones file
@@ -27,22 +10,20 @@
              of the .edi file is given its own class, so the elements of each
              section are attributes for easy access.
              ...
-
-Created on Thu Dec  3 22:31:16 2020
-
-@author: @Daniel03
 """
-import os , re, warnings
-import datetime, shutil
+import os 
+import re
+import shutil
+import warnings
+import datetime
 import webbrowser
 import numpy as np 
 
-
-import pycsamt.ff.core.cs  as cs_obj
-from pycsamt.etc.infos import notion
-
-from pycsamt.ff.core.edi import Edi, Hmeasurement, Emeasurement 
-from pycsamt.etc.infos import _sensitive as SB 
+from pycsamt.ff.site import Site, Location, Profile 
+from pycsamt.utils._p import notion
+from pycsamt.ff.core.edi import (Edi, Hmeasurement, Emeasurement) 
+from pycsamt.utils._p import _sensitive as SB 
+from pycsamt.utils.decorator import deprecated
 import pycsamt.utils.func_utils as func
 from pycsamt.utils import exceptions as CSex
 from pycsamt.utils._csamtpylog import csamtpylog
@@ -109,8 +90,8 @@ class J_collection :
         self.survey_name =survey_name
         
         self.J=J()
-        self.Location =cs_obj.Location ()
-        self.Site =cs_obj.Site()
+        self.Location =Location ()
+        self.Site =Site()
         
         self._latitude =None 
         self._longitude =None
@@ -136,7 +117,12 @@ class J_collection :
         self.weight =None
         self.loc =None 
         self.id =None 
-        
+       
+        for key in list(kwargs.keys()): 
+            setattr(self, key, kwargs[key])
+            
+        if not hasattr(self, 'savepath'):
+            setattr(self, 'savepath' , None)
 
         if self.jfiles_list is not None :
             self.collect_jfiles()
@@ -190,12 +176,13 @@ class J_collection :
                 raise CSex.pyCSAMTError_J(
                     'Stations names must be on list or the number'
                     ' of stations not <{0}>.'.format(type(jstnames)))
+                
     
-
+    @deprecated("Use `pycsamt.ff.core.CSAMT.j2edi ` instead.")
     def j2edi(self, jfn=None, savepath =None, **kwargs): 
         """
-        Method to convert j-files to edi files. Method calls CSAMT class object
-        and get from this class edi infos 
+        Method to convert j-files to edi files. Method calls CSAMT 
+        class objectand get from this class edi infos. 
         
         :param jfn: collection of jfiles or path-like str  
         :type list_of_files: str  
@@ -208,9 +195,11 @@ class J_collection :
             >>> from pycsamt.ff.core.j import J_collection as JObjs
             >>> path2j = 'data/j' 
             >>> jObjs= JObjs().j2edi(path2j)
-            
-    
+  
         """
+        #####################################################################
+        import pycsamt.ff.core.cs  as cs_obj
+        #####################################################################
         prospect =kwargs.pop('contractor_name', None)
         #hardwareInfos = kwargs.pop('hardware_name', None)
         fileby =kwargs.pop('fileby', 'jediSoftware')
@@ -252,7 +241,7 @@ class J_collection :
                 csamt_jobj.jsites_infos = datetime.datetime.fromtimestamp(
                     os.stat(jfn).st_ctime) # return the creation date of file 
                 
-            edi_obj.Head.acqdate = csamt_jobj.jsites_infos 
+            edi_obj.Head.acqdate = csamt_jobj.jsites_infos
             edi_obj.Head.fileby = fileby 
             edi_obj.Head.filedate = datetime.datetime.now(
                 ).strftime('%m-%d-%Y %H:%M:%S')
@@ -539,7 +528,10 @@ class J_collection :
         elif self.jfiles_list is not None :
             self.collect_jfiles(list_of_jfiles =self.jfiles_list )
             
+        #######################################################################
         from pycsamt.viewer.plot import Plot1d 
+        #######################################################################
+        
         #--> create Plot1d Obj 
         plot_obj= Plot1d()
         #--> get easting northing arrays after converting from lat, lon
@@ -548,7 +540,7 @@ class J_collection :
                                                                            
 
         # ----> compute station separation using Profile obj 
-        jstn_separation = cs_obj.Profile().stn_separation(
+        jstn_separation = Profile().stn_separation(
             easting =jeasting , northing =jnorthing)[0]
        
         #---- > interpolate Jstn_separation  so to get the same size as stations.
@@ -559,7 +551,6 @@ class J_collection :
 
         jstn_separation_extrap = ff(xx_new)
 
-        
         if compute_azimuth is True :
 
             self.azimuth =func.compute_azimuth(
@@ -607,8 +598,14 @@ class J_collection :
         :type savepath: str   
         """
         
-        if list_of_jfiles is not None : self.jfiles_list =list_of_jfiles 
-        if survey_name is not None : self.survey_name =survey_name 
+        if list_of_jfiles is not None :
+            self.jfiles_list =list_of_jfiles 
+        if survey_name is not None : 
+            self.survey_name =survey_name 
+            
+        if savepath is not None: 
+            self.savepath = savepath 
+            
         if self.jfiles_list is  None : 
             raise CSex.pyCSAMTError_J(
                 'No files found to read . '
@@ -616,7 +613,6 @@ class J_collection :
         elif self.jfiles_list is not None : 
             self.collect_jfiles(list_of_jfiles =self.jfiles_list )
          
-            
         #--- > start writing 
         write_jlines =[]
         if self.survey_name is None :
@@ -625,6 +621,9 @@ class J_collection :
             code_name = self.survey_name[:-3]+'{0:02}-{1}'
         codespace= 5*' '
         
+        # create a path if not exist and move the file(s).
+        self.savepath = func.cpath (self.savepath ,'_outrewritej_')
+        
         for ii in range (len(self.id)) : 
             #-- > write Head j 
             write_jlines.append(''.join(
@@ -734,17 +733,16 @@ class J_collection :
                       encoding='utf8') as fj:
                 fj.writelines(write_jlines)
             
-                
-            if savepath is not None : 
+            
+            if self.savepath is not None : 
                 shutil.move ('{0}{1}'.format(
-                    self.id[ii],j_extension), savepath)
+                    self.id[ii],j_extension), self.savepath)
                                                            
             write_jlines=[]  
             
         print('-'*77) 
-        if savepath is None :savepath =os.getcwd()
         print('---> {0} J-files have been rewritten to <{1}>'
-              ' <----'.format(len(self.id), savepath))
+              ' <----'.format(len(self.id), self.savepath))
         print('-'*77)
                                                             
 
@@ -1045,7 +1043,8 @@ class J:
         return self._jweight
     @jweight.setter 
     def jweight (self, jweight):
-        if jweight is None : self._jweight = np.full((self.japp_rho.size,),1.)
+        if jweight is None : 
+            self._jweight = np.full((self.japp_rho.size,),1.)
         for ii, item in enumerate(jweight): 
             if item in ['','*'] or item == str(self._jnan): 
                 jweight[ii]=np.nan
