@@ -1,26 +1,9 @@
 #!/usr/bin/env python
+#       Authors: Lars Krieger, Jared R. Peacock & Alison Louise Kirkby
+#       contact: < https://github.com/MTgeophysics/mtpy.git>
+#       Licence: GPL
 
 """
-===============================================================================
-    Copyright © 2021  Kouadio K. Laurent
-    
-    This file is part of pyCSAMT.
-    
-    pyCSAMT is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    pyCSAMT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-    
-    You should have received a copy of the GNU Lesser General Public License
-    along with pyCSAMT.  If not, see <https://www.gnu.org/licenses/>.
-
-===============================================================================    
-
 .. module:: Z
    :synopsis: Deal with MT responses Z and Tipper
         Module belongs to  MTpy .see  https://mtpy2.readthedocs.io/en/develop/ 
@@ -33,23 +16,17 @@
         Journal of Open Source Software, 4(37), 1358. https://doi.org/10.21105/joss.01358
         ...
 
-.. moduleauthor:: Jared Peacock <jpeacock@usgs.gov>
-.. moduleauthor:: Lars Krieger
-
-.. edited ::  @Daniel03
 """
 
 import cmath
 import copy
 import math
-
-# =================================================================
 import numpy as np
+# =================================================================
 
-import pycsamt.ff.processing.mtcalculator as MTcc
+import pycsamt.utils.mtcalculator as MTcc
 import pycsamt.utils.exceptions as MTex
 from pycsamt.utils._csamtpylog import csamtpylog
-
 _logger = csamtpylog.get_csamtpy_logger(__name__)
 
 
@@ -60,8 +37,6 @@ class ResPhase(object):
     """
     resistivity and phase container
     .. module:: Z
-    .. moduleauthor:: Jared Peacock <jpeacock@usgs.gov>
-    .. moduleauthor:: Lars Krieger
     """
 
     def __init__(self, z_array=None, z_err_array=None, freq=None, **kwargs):
@@ -205,8 +180,9 @@ class ResPhase(object):
                 for jj in range(2):
                     abs_z = np.sqrt(5 * self.freq[idx_f] * \
                                     self.resistivity[idx_f, ii, jj])
-                    rel_error_res = self.resistivity_err[idx_f, ii, jj] / \
-                                    self.resistivity[idx_f, ii, jj]
+                    with np.errstate(all='ignore'): 
+                        rel_error_res = self.resistivity_err[idx_f, ii, jj] / \
+                                        self.resistivity[idx_f, ii, jj]
                     # relative error varies by a factor of 0.5, which is the
                     # exponent in the relation between them:
                     abs_z_error = 0.5 * abs_z * rel_error_res
