@@ -1,40 +1,22 @@
 # -*- coding: utf-8 -*-
+#       Created on Tue Dec 29 19:18:44 2020
+#       This module is a part of pycsamt utils packages
+#       Author: Kouadio K.Laurent<etanoyau@gmail.com>
+#       Licence: LGPL
 """
-===============================================================================
-    Copyright © 2021  Kouadio K.Laurent
-    
-    This file is part of pyCSAMT.
-    
-    pyCSAMT is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    pyCSAMT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-    
-    You should have received a copy of the GNU Lesser General Public License
-    along with pyCSAMT.  If not, see <https://www.gnu.org/licenses/>.
-
-===============================================================================
-
 .. _module-Plot_Utils:: `pycsamt.utils.plot_utils` 
     :synopsis: helpers functions for visualization 
-    
-Created on Tue Dec 29 19:18:44 2020
-
-@author: @Daniel03
 """
-import re , os, warnings
+# import re
+import os
+import warnings
 import numpy as np
-from pycsamt.etc.infos import _sensitive as SB
-import matplotlib as mpl 
-import matplotlib.cm as cm 
-import matplotlib.pyplot as plt
+# import matplotlib as mpl 
+# import matplotlib.cm as cm 
+# import matplotlib.pyplot as plt
+from pycsamt.utils._p import _sensitive as SB
 from pycsamt.utils import exceptions as CSex 
-from pycsamt.utils.decorator import deprecated, redirect_cls_or_func
+from pycsamt.utils.decorator import (deprecated, deprecated_to)
 
 
 def share_props_for_each_plot(number_of_plot = 3 ,  **kwargs):
@@ -167,7 +149,7 @@ def station_id (id_):
     From id get the station  name as input  and return index `id`. 
     Index starts at 0.
     
-    :param id_: name of the station or index . Be sure to hve the station name 
+    :param id_: name of the station or index . Be sure to have the station name 
         containing the letter `S` which mean `site`. 
     :return: station index. If the list `id_` is given 
             will return the tuple.
@@ -661,7 +643,7 @@ def slice_csamt_matrix ( block_matrix , station_offsets,
     
     #check wheren the value provide is on the offset 
     if offset_min < offset_start : 
-        warnings.warn ('Povided minimal offset is out of the range '
+        warnings.warn ('Provide minimal offset is out of the range '
                        '!Offset minimal for plottig is ={0}'.format(
                            offset_start))
         raise CSex.pyCSAMTError_plot_tip(
@@ -904,7 +886,8 @@ def build_new_station_id (station_id , new_station_name ):
     return [str(id_) for id_ in station_id] , mess
 
 def get_conductive_and_resistive_zone (data, site_names,
-                                       purpose ='groundwater',**kws): 
+                                       purpose ='groundwater',
+                                       **kws): 
     """
     function to get the probability of conductive and resistive zone .
     It is not absolutely True but give an overview of decison .
@@ -1077,9 +1060,9 @@ def get_conductive_and_resistive_zone (data, site_names,
         print()
         print( '!IMPORTANT NOTE! :')
         bfreport =''.join(['This present report is',
-                           '  for {0}  exploration purpose.',  
-                           'If your survey purpose if far from',
-                           ' {0} exploration , please ignore it.'])
+                           ' for {0}  exploration purpose. ',  
+                           'If yoursurvey purpose if far from',
+                           ' {0} exploration, please ignore it.'])
         bfreport =bfreport.format(purpose)
         
         fttext = fmt_text(data_text = bfreport, fmt='-', leftspace=3)
@@ -1091,7 +1074,7 @@ def get_conductive_and_resistive_zone (data, site_names,
         report=''.join([
             'In the case of {0} exploration, along the survey line,',
             ' site {1} seems to be the best conductive zone with reliability ',
-            ' ratio estimates to  = {2} % compared to the threshold = {3} %.',
+            ' ratio estimates to = {2} % compared to the threshold = {3} %.',
             ' {4} Site {1} is considered as {5}. '
                     ])
         report= report.format(purpose, 
@@ -1101,7 +1084,7 @@ def get_conductive_and_resistive_zone (data, site_names,
                               fm, 
                               mess)
         caution =''.join([
-            'The present  report is NOT absolute. It might be',
+            'The present report is NOT absolute. It might be',
             ' taken with cautiousness because in groundwater ', 
             ' exploration, many other parameters are considering',
             ' before a possible drilling decison. We hope in  ', 
@@ -1389,7 +1372,7 @@ def average_rho_in_deeper (dep_array, rho_array, step_descent ) :
 
 @deprecated("function deprecated , it's does not cover the total depth when "
             "last value is outside the model depth range. ")
-@redirect_cls_or_func(average_rho_in_deeper,"Function replaced ,"
+@deprecated_to(average_rho_in_deeper,"Function replaced ,"
                       " it redirects to {average_rho_in_deeper}.")
 def average_rho_in_deep (dep_array, rho_array, step_descent)   :
     """
@@ -1531,7 +1514,7 @@ def build_resistivity_barplot(depth_values , res_values):
     
     Parameters
     ----------
-        * depth_values : aray_like 
+        * depth_values : array_like 
                 model investigation depth 
                 
         * res_values : array_like 
@@ -1652,7 +1635,8 @@ def annotate_tip(layer_thickness , layer_names):
                 if layer_names[ii].lower() != layer_names[ii-1].lower() :  
                     mean =top + (layer_thickness[ii-1]-top)/2
                     v.append(mean)
-                    mean = layer_thickness[ii-1] + (thickvalues- layer_thickness[ii-1])/2  
+                    mean = layer_thickness[ii-1] + (
+                        thickvalues- layer_thickness[ii-1])/2  
                     v.append(mean)
                     ni.append(layer_names[ii])                
             
